package com.infinitenotions.sample.storage;

import java.util.ArrayList;

import com.infinitenotions.sample.storagefunc.ExternalStorage;
import com.infinitenotions.sample.storagefunc.InternalStorage;

import android.app.*;
import android.os.*;
import android.view.*;
import android.view.View.OnClickListener;
import android.widget.*;

public class SSampleActivity extends Activity implements OnClickListener
{
	private EditText mItemTextEt;
	private Spinner mItemSpn;
	private Button mAddItemBtn;
	private Button mRemoveItemBtn;
	private Button mSaveInternalBtn;
	private Button mSaveExternalBtn;
	private Button mLoadInternalBtn;
	private Button mLoadExternalBtn;
	
	private ArrayList<String> mItemList;
	private ArrayAdapter<String> mSpinnerAdapter;
	private InternalStorage mIternalStorage;
	private ExternalStorage mExternalStorage;
	
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
	{
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        mItemList = new ArrayList<String>();
        mIternalStorage = new InternalStorage();
        mExternalStorage = new ExternalStorage();
        
        mItemTextEt = (EditText)findViewById(R.id.itemTextET);
        
        mItemSpn = (Spinner)findViewById(R.id.itemSP);
        mSpinnerAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_dropdown_item, mItemList);
        mItemSpn.setAdapter(mSpinnerAdapter);
        
        mAddItemBtn = (Button)findViewById(R.id.addItemBtn);
        mAddItemBtn.setOnClickListener(this);
        
        mRemoveItemBtn = (Button)findViewById(R.id.removeItemBtn);
        mRemoveItemBtn.setOnClickListener(this);
        
        mSaveInternalBtn = (Button)findViewById(R.id.saveInternalStorageBtn);
        mSaveInternalBtn.setOnClickListener(this);
        
        mSaveExternalBtn = (Button)findViewById(R.id.saveExternalStorageBtn);
        mSaveExternalBtn.setOnClickListener(this);
        
        mLoadInternalBtn = (Button)findViewById(R.id.loadInternalStorageBtn);
        mLoadInternalBtn.setOnClickListener(this);
        
        mLoadExternalBtn = (Button)findViewById(R.id.loadExternalStorageBtn);
        mLoadExternalBtn.setOnClickListener(this);
    }


	@Override
	public void onClick(View v)
	{
		switch (v.getId())
		{
			case R.id.addItemBtn:
				String item = mItemTextEt.getText().toString();
				
				if (item.isEmpty())
				{
					return;
				}
				
				mItemList.add(item);
				mSpinnerAdapter.notifyDataSetChanged();
				mItemTextEt.setText("");
				break;
			case R.id.removeItemBtn:
				if (mItemSpn.getSelectedItemPosition() < 0)
				{
					return;
				}
				
				mItemList.remove(mItemSpn.getSelectedItemPosition());
				mSpinnerAdapter.notifyDataSetChanged();
				break;
			case R.id.saveInternalStorageBtn:
				mIternalStorage.storeListAsJson(this, mItemList);
				break;
			case R.id.saveExternalStorageBtn:
				mExternalStorage.storeListAsJson(mItemList);
				break;
			case R.id.loadInternalStorageBtn:
				mItemList.clear();
				mItemList.addAll(mIternalStorage.loadListAsJson(this));
				mSpinnerAdapter.notifyDataSetChanged();
				break;
			case R.id.loadExternalStorageBtn:
				mItemList.clear();
				mItemList.addAll(mExternalStorage.loadListAsJson());
				mSpinnerAdapter.notifyDataSetChanged();
				break;
		}
	}
}
